@@ -1,36 +1,21 @@
 #!/bin/env python
 
-import logging.config
+import logging
 import os
 import sys
 import subprocess
 from time import gmtime, strftime
+from datetime import datetime, date, timedelta
 import yaml
 from influxdb import InfluxDBClient
-from datetime import datetime, date, timedelta
 import psycopg2
 import click
 from fdsnextender import FdsnExtender
 
+logging.basicConfig(format='%(asctime)s %(levelname)s: %(message)s', level=logging.INFO)
 logger = logging.getLogger(__name__)
 
 
-def validate_config(cfg):
-    """
-    Validate configuration
-    """
-    # Logger file exists and is readable ?
-
-    return True
-
-
-def dict_dumper(dict):
-    try:
-        return dict.toJSON()
-    except:
-        return dict.__dict__
-
-
 def scan_volume(path):
     """
     Scanne un volume indiqué par son chemin (path).
@@ -47,7 +32,7 @@ def scan_volume(path):
         ["du", "--exclude", ".snapshot", "-b", "-d4", volume]).decode("utf-8").splitlines()
     logger.debug("Volume scanned in %s", datetime.now() - starttime)
     for l in lines:
-        logger.debug(l)
+        logger.debug("Scanning %s",l)
         (size, path) = l.split('\t')
         # On ne garde que le chemin qui nous intéresse
         path = path.replace(volume, '').split('/')
@@ -55,8 +40,9 @@ def scan_volume(path):
         if len(path) == 4:
             logger.debug("path: %s, size: %s", path, size)
             (channel, quality) = path[3].split('.')
-            data.append({'year': path[0], 'network': path[1], 'station': path[2],
+            data.append({'year': path[1], 'network': path[0], 'station': path[2],
                          'channel': channel, 'quality': quality, 'size': size})
+            logger.debug(data[-1])
     return data
 
 
@@ -90,24 +76,22 @@ def scan_volumes(volumes):
 @click.option('--config-file',  'configfile', type=click.File(), help='Configuration file path', envvar='CONFIG_FILE', show_default=True,
               default=f"{os.path.dirname(os.path.realpath(__file__))}/config.yml")
 @click.option('--force-scan', flag_value=True, default=False, help='Force scanning of the archive')
-def cli(configfile, force_scan):
+@click.option('--dryrun', flag_value=True, default=False, help="Do not send metrics to database")
+@click.option("--verbose", flag_value=True, default=False, help="Verbose mode")
+def cli(configfile, force_scan, dryrun, verbose):
     """
     Command line interface. Stands as main
     """
+    if verbose:
+        logger.setLevel(logging.DEBUG)
+    logger.info("Starting")
     try:
         cfg = yaml.load(configfile, Loader=yaml.SafeLoader)
     except:
         print(f"Error reading file {configfile}")
 
-    validate_config(cfg)
     # At this point we ensure that configuration is sane.
 
-    logger_file = cfg['logger_file']
-    if not logger_file.startswith('/'):
-        logger_file = os.path.split(configfile.name)[0]+'/'+logger_file
-    logging.config.fileConfig(logger_file)
-    logger = logging.getLogger("resif_data_reporter")
-    logger.info("Starting")
     statistics = []
     today = date.today().strftime("%Y-%m-%d")
 
@@ -155,6 +139,9 @@ def cli(configfile, force_scan):
     except:
         logger.error("Error writing data to cache")
 
+    if dryrun:
+        logger.info("Dryrun mode, exit")
+        sys.exit(0)
         # Write to postgres database
     if 'postgres' in cfg:
         logger.info('Writing to postgres database')
@@ -219,3 +206,6 @@ def cli(configfile, force_scan):
         except Exception as e:
             logger.error("Unexpected error writing data to influxdb")
             logger.error(e)
+
+if __name__ == "__main__":
+    cli()
